{% extends "base.html" %}
{% load kegweblib crispy_forms_tags %}

{% block title %}Reset Password{% endblock %}

{% block content %}
<h2>Reset Complete</h2>
<p>
  Your account has been updated!
</p>
{% endblock %}
