{% load kegweblib %}

<li class="nav-header">Kegbot Admin</a>
{% navitem "kegadmin-dashboard" "Dashboard" exact %}

<li class="nav-header">Settings</a>
{% navitem "kegadmin-main" "General" %}
{% navitem "kegadmin-location-settings" "Location" %}
{% navitem "kegadmin-advanced-settings" "Advanced" %}
{% if not EMBEDDED %}
{% navitem "kegadmin-email" "E-Mail" %}
{% endif %}

<li class="nav-header">System</li>
{% if ENABLE_SENSING %}
  {% navitem "kegadmin-controllers" "Controllers" %}
{% endif %}

{% navitem "kegadmin-taps" "Taps" %}
{% navitem "kegadmin-kegs" "Keg Room" %}

{% if ENABLE_SENSING %}
  {% navitem "kegadmin-drinks" "Drinks" %}
{% endif %}
{% if ENABLE_USERS %}
  {% navitem "kegadmin-users" "Users" %}
  {% navitem "kegadmin-tokens" "Tokens" %}
{% endif %}

<li class="nav-header">Beer DB</li>
{% navitem "kegadmin-beverage-producers" "Brewers" %}
{% navitem "kegadmin-beverages" "Beer Types" %}

{% if PLUGINS %}
<li class="nav-header">Plugins</li>
{% for plugin in PLUGINS.values %}
  {% if plugin.get_admin_settings_view %}
    {% url "kegadmin-plugin-settings" plugin_name=plugin.get_short_name as settings_url %}
    {% navitem settings_url plugin.get_name %}
  {% endif %}
{% endfor %}
{% endif %}

<li class="divider"></li>
<li class="nav-header">Other</li>
{% if not EMBEDDED %}
{% navitem "kegadmin-logs" "Logs" %}
{% endif %}
{% navitem "kegadmin-export" "Export Data" %}
{% if HAVE_ADMIN and not EMBEDDED %}
{% navitem "kegadmin-workers" "Worker Status" %}
<li><a href='{% url "admin:index" %}' target="_blank">Database Admin &raquo;</a></li>
{% endif %}
<li><a href='https://github.com/Kegbot/kegbot-server/issues' target="_blank">Report a Bug &raquo;</a></li>
