{% extends 'notification/email_base.html' %}

{% block subject %}[{{ site_name }}] Complete your registration{% endblock %}

{% block body_plain %}
You just signed up for an account on {{ site_name }} -- welcome!

To complete your registration and activate your account, please
click here: {{ url }}
{% endblock %}

{% block body_html %}
<p>
You just signed up for an account on {{ site_name }} -- welcome!
</p>

<p>
To complete your registration and activate your account, please
click here: <a href="{{ url }}">{{ url }}</a>
</p>
{% endblock %}
