{% load kegweblib %}

<ul class="nav nav-tabs">
    {% navitem "kegadmin-kegs" "All Kegs" exact %}
    {% navitem "kegadmin-kegs-online" "On Tap" %}
    {% navitem "kegadmin-kegs-available" "Available" %}
    {% navitem "kegadmin-kegs-kicked" "Kicked" %}
    {% navitem "kegadmin-add-keg" "New Keg" %}
</ul>